@@ -133,6 +133,36 @@ class PlayerStats (object):
                 n += v
         return n
 
+    @property
+    def twopta(self):
+        """
+        Returns the total number of two point conversion attempts for
+        the passing, rushing and receiving categories.
+        """
+        return (self.passing_twopta
+                + self.rushing_twopta
+                + self.receiving_twopta)
+
+    @property
+    def twoptm(self):
+        """
+        Returns the total number of two point conversions for
+        the passing, rushing and receiving categories.
+        """
+        return (self.passing_twoptm
+                + self.rushing_twoptm
+                + self.receiving_twoptm)
+
+    @property
+    def twoptmissed(self):
+        """
+        Returns the total number of two point conversion failures for
+        the passing, rushing and receiving categories.
+        """
+        return (self.passing_twoptmissed
+                + self.rushing_twoptmissed
+                + self.receiving_twoptmissed)
+
     @property
     def stats(self):
         """
